@@ -4,7 +4,7 @@ from pathlib import Path
 
 
 def determine_gain_ref(gain_ref_dir: Path) -> Path:
-    candidates = list(gain_ref_dir.glob("*"))
+    candidates = list(gain_ref_dir.glob("**/*"))
     candidates = sorted(candidates, key=lambda x: x.stat().st_mtime, reverse=True)
     viable_candidates = candidates[:3]
     viable_candidates = sorted(
